@@ -4,6 +4,6 @@ mod resolver;
 mod typeshed;
 
 pub use db::{Db, Jar};
-pub use module::{ModuleKind, ModuleName};
+pub use module::{Module, ModuleKind, ModuleName};
 pub use resolver::{resolve_module, set_module_resolution_settings, ModuleResolutionSettings};
 pub use typeshed::versions::TypeshedVersions;
