@@ -4,7 +4,8 @@ use ruff_db::{Db as SourceDb, Upcast};
 
 use red_knot_module_resolver::Db as ResolverDb;
 
-use crate::semantic_index::symbol::{public_symbols_map, scopes_map, PublicSymbolId, ScopeId};
+use crate::semantic_index::definition::Definition;
+use crate::semantic_index::symbol::{public_symbols_map, PublicSymbolId, ScopeId};
 use crate::semantic_index::{root_scope, semantic_index, symbol_table};
 use crate::types::{infer_types, public_symbol_ty};
 
@@ -12,8 +13,8 @@ use crate::types::{infer_types, public_symbol_ty};
 pub struct Jar(
     ScopeId<'_>,
     PublicSymbolId<'_>,
+    Definition<'_>,
     symbol_table,
-    scopes_map,
     root_scope,
     semantic_index,
     infer_types,
