@@ -1,16 +1,10 @@
-use salsa::DebugWithDb;
-
 use ruff_db::parsed::parsed_module;
 use ruff_db::vfs::VfsFile;
 use ruff_index::newtype_index;
-use ruff_python_ast as ast;
+use ruff_python_ast::name::Name;
 
-use crate::name::Name;
-use crate::semantic_index::ast_ids::{AstIdNode, ScopeAstIdNode};
-use crate::semantic_index::symbol::{FileScopeId, PublicSymbolId, ScopeId};
-use crate::semantic_index::{
-    public_symbol, root_scope, semantic_index, symbol_table, NodeWithScopeId,
-};
+use crate::semantic_index::symbol::{FileScopeId, NodeWithScopeKind, PublicSymbolId, ScopeId};
+use crate::semantic_index::{public_symbol, root_scope, semantic_index, symbol_table};
 use crate::types::infer::{TypeInference, TypeInferenceBuilder};
 use crate::Db;
 use crate::FxIndexSet;
@@ -18,28 +12,6 @@ use crate::FxIndexSet;
 mod display;
 mod infer;
 
-/// Infers the type of `expr`.
-///
-/// Calling this function from a salsa query adds a dependency on [`semantic_index`]
-/// which changes with every AST change. That's why you should only call
-/// this function for the current file that's being analyzed and not for
-/// a dependency (or the query reruns whenever a dependency change).
-///
-/// Prefer [`public_symbol_ty`] when resolving the type of symbol from another file.
-#[tracing::instrument(level = "debug", skip(db))]
-pub(crate) fn expression_ty<'db>(
-    db: &'db dyn Db,
-    file: VfsFile,
-    expression: &ast::Expr,
-) -> Type<'db> {
-    let index = semantic_index(db, file);
-    let file_scope = index.expression_scope_id(expression);
-    let expression_id = expression.scope_ast_id(db, file, file_scope);
-    let scope = file_scope.to_scope_id(db, file);
-
-    infer_types(db, scope).expression_ty(expression_id)
-}
-
 /// Infers the type of a public symbol.
 ///
 /// This is a Salsa query to get symbol-level invalidation instead of file-level dependency invalidation.
@@ -66,7 +38,7 @@ pub(crate) fn expression_ty<'db>(
 /// This being a query ensures that the invalidation short-circuits if the type of this symbol didn't change.
 #[salsa::tracked]
 pub(crate) fn public_symbol_ty<'db>(db: &'db dyn Db, symbol: PublicSymbolId<'db>) -> Type<'db> {
-    let _ = tracing::trace_span!("public_symbol_ty", symbol = ?symbol.debug(db)).enter();
+    let _span = tracing::trace_span!("public_symbol_ty", ?symbol).entered();
 
     let file = symbol.file(db);
     let scope = root_scope(db, file);
@@ -75,8 +47,9 @@ pub(crate) fn public_symbol_ty<'db>(db: &'db dyn Db, symbol: PublicSymbolId<'db>
     inference.symbol_ty(symbol.scoped_symbol_id(db))
 }
 
-/// Shorthand for `public_symbol_ty` that takes a symbol name instead of a [`PublicSymbolId`].
-pub fn public_symbol_ty_by_name<'db>(
+/// Shorthand for [`public_symbol_ty()`] that takes a symbol name instead of a [`PublicSymbolId`].
+#[allow(unused)]
+pub(crate) fn public_symbol_ty_by_name<'db>(
     db: &'db dyn Db,
     file: VfsFile,
     name: &str,
@@ -88,38 +61,29 @@ pub fn public_symbol_ty_by_name<'db>(
 /// Infers all types for `scope`.
 #[salsa::tracked(return_ref)]
 pub(crate) fn infer_types<'db>(db: &'db dyn Db, scope: ScopeId<'db>) -> TypeInference<'db> {
-    let _ = tracing::trace_span!("infer_types", scope = ?scope.debug(db)).enter();
+    let _span = tracing::trace_span!("infer_types", ?scope).entered();
 
     let file = scope.file(db);
     // Using the index here is fine because the code below depends on the AST anyway.
     // The isolation of the query is by the return inferred types.
     let index = semantic_index(db, file);
 
-    let scope_id = scope.file_scope_id(db);
-    let node = index.scope_node(scope_id);
+    let node = scope.node(db);
 
     let mut context = TypeInferenceBuilder::new(db, scope, index);
 
     match node {
-        NodeWithScopeId::Module => {
+        NodeWithScopeKind::Module => {
             let parsed = parsed_module(db.upcast(), file);
             context.infer_module(parsed.syntax());
         }
-        NodeWithScopeId::Class(class_id) => {
-            let class = ast::StmtClassDef::lookup(db, file, class_id);
-            context.infer_class_body(class);
+        NodeWithScopeKind::Function(function) => context.infer_function_body(function.node()),
+        NodeWithScopeKind::Class(class) => context.infer_class_body(class.node()),
+        NodeWithScopeKind::ClassTypeParameters(class) => {
+            context.infer_class_type_params(class.node());
         }
-        NodeWithScopeId::ClassTypeParams(class_id) => {
-            let class = ast::StmtClassDef::lookup(db, file, class_id);
-            context.infer_class_type_params(class);
-        }
-        NodeWithScopeId::Function(function_id) => {
-            let function = ast::StmtFunctionDef::lookup(db, file, function_id);
-            context.infer_function_body(function);
-        }
-        NodeWithScopeId::FunctionTypeParams(function_id) => {
-            let function = ast::StmtFunctionDef::lookup(db, file, function_id);
-            context.infer_function_type_params(function);
+        NodeWithScopeKind::FunctionTypeParameters(function) => {
+            context.infer_function_type_params(function.node());
         }
     }
 
@@ -271,6 +235,18 @@ impl<'a> FunctionType<'a> {
     }
 }
 
+impl<'db> TypeId<'db, ScopedFunctionTypeId> {
+    pub fn name<'a>(self, context: &'a TypingContext<'db, 'a>) -> &'a Name {
+        let function_ty = self.lookup(context);
+        &function_ty.name
+    }
+
+    pub fn has_decorator(self, context: &TypingContext, decorator: Type<'db>) -> bool {
+        let function_ty = self.lookup(context);
+        function_ty.decorators.contains(&decorator)
+    }
+}
+
 #[newtype_index]
 pub struct ScopedClassTypeId;
 
@@ -283,14 +259,42 @@ impl ScopedTypeId for ScopedClassTypeId {
 }
 
 impl<'db> TypeId<'db, ScopedClassTypeId> {
+    pub fn name<'a>(self, context: &'a TypingContext<'db, 'a>) -> &'a Name {
+        let class_ty = self.lookup(context);
+        &class_ty.name
+    }
+
     /// Returns the class member of this class named `name`.
     ///
     /// The member resolves to a member of the class itself or any of its bases.
-    fn class_member(self, context: &TypingContext<'db, '_>, name: &Name) -> Option<Type<'db>> {
+    pub fn class_member(self, context: &TypingContext<'db, '_>, name: &Name) -> Option<Type<'db>> {
         if let Some(member) = self.own_class_member(context, name) {
             return Some(member);
         }
 
+        self.inherited_class_member(context, name)
+    }
+
+    /// Returns the inferred type of the class member named `name`.
+    pub fn own_class_member(
+        self,
+        context: &TypingContext<'db, '_>,
+        name: &Name,
+    ) -> Option<Type<'db>> {
+        let class = self.lookup(context);
+
+        let symbols = symbol_table(context.db, class.body_scope);
+        let symbol = symbols.symbol_id_by_name(name)?;
+        let types = context.types(class.body_scope);
+
+        Some(types.symbol_ty(symbol))
+    }
+
+    pub fn inherited_class_member(
+        self,
+        context: &TypingContext<'db, '_>,
+        name: &Name,
+    ) -> Option<Type<'db>> {
         let class = self.lookup(context);
         for base in &class.bases {
             if let Some(member) = base.member(context, name) {
@@ -300,17 +304,6 @@ impl<'db> TypeId<'db, ScopedClassTypeId> {
 
         None
     }
-
-    /// Returns the inferred type of the class member named `name`.
-    fn own_class_member(self, context: &TypingContext<'db, '_>, name: &Name) -> Option<Type<'db>> {
-        let class = self.lookup(context);
-
-        let symbols = symbol_table(context.db, class.body_scope);
-        let symbol = symbols.symbol_id_by_name(name)?;
-        let types = context.types(class.body_scope);
-
-        Some(types.symbol_ty(symbol))
-    }
 }
 
 #[derive(Debug, Eq, PartialEq, Clone)]
@@ -506,6 +499,7 @@ impl<'db, 'inference> TypingContext<'db, 'inference> {
 
 #[cfg(test)]
 mod tests {
+    use red_knot_module_resolver::{set_module_resolution_settings, ModuleResolutionSettings};
     use ruff_db::file_system::FileSystemPathBuf;
     use ruff_db::parsed::parsed_module;
     use ruff_db::vfs::system_path_to_file;
@@ -514,8 +508,8 @@ mod tests {
         assert_will_not_run_function_query, assert_will_run_function_query, TestDb,
     };
     use crate::semantic_index::root_scope;
-    use crate::types::{expression_ty, infer_types, public_symbol_ty_by_name, TypingContext};
-    use red_knot_module_resolver::{set_module_resolution_settings, ModuleResolutionSettings};
+    use crate::types::{infer_types, public_symbol_ty_by_name, TypingContext};
+    use crate::{HasTy, SemanticModel};
 
     fn setup_db() -> TestDb {
         let mut db = TestDb::new();
@@ -542,8 +536,9 @@ mod tests {
         let parsed = parsed_module(&db, a);
 
         let statement = parsed.suite().first().unwrap().as_assign_stmt().unwrap();
+        let model = SemanticModel::new(&db, a);
 
-        let literal_ty = expression_ty(&db, a, &statement.value);
+        let literal_ty = statement.value.ty(&model);
 
         assert_eq!(
             format!("{}", literal_ty.display(&TypingContext::global(&db))),
