@@ -68,41 +68,3 @@ def func():
     np.longfloat(12+34j)
 
     np.lookfor
-
-    np.obj2sctype(int)
-
-    np.PINF
-
-    np.PZERO
-
-    np.recfromcsv
-
-    np.recfromtxt
-
-    np.round_(12.34)
-
-    np.safe_eval
-
-    np.sctype2char
-
-    np.sctypes
-
-    np.seterrobj
-
-    np.set_numeric_ops
-
-    np.set_string_function
-
-    np.singlecomplex(12+1j)
-
-    np.string_("asdf")
-
-    np.source
-
-    np.tracemalloc_domain
-
-    np.unicode_("asf")
-
-    np.who()
-
-    np.row_stack(([1,2], [3,4]))
