@@ -55,7 +55,11 @@ impl Debug for DebugComments<'_> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         let mut map = f.debug_map();
 
-        for node in self.comments.keys().sorted_by_key(|key| key.node().start()) {
+        for node in self
+            .comments
+            .keys()
+            .sorted_by_key(|key| (key.node().start(), key.node().end()))
+        {
             map.entry(
                 &NodeKindWithSource {
                     key: *node,
@@ -191,11 +195,11 @@ mod tests {
     #[test]
     fn debug() {
         let continue_statement = AnyNode::from(StmtContinue {
-            range: TextRange::default(),
+            range: TextRange::new(TextSize::new(18), TextSize::new(26)),
         });
 
         let break_statement = AnyNode::from(StmtBreak {
-            range: TextRange::default(),
+            range: TextRange::new(TextSize::new(55), TextSize::new(60)),
         });
 
         let source = r"# leading comment
