@@ -177,16 +177,31 @@ impl<'a> Binding<'a> {
             | BindingKind::Builtin => {
                 return false;
             }
+            // Assignment-assignment bindings are not considered redefinitions, as in:
+            // ```python
+            // x = 1
+            // x = 2
+            // ```
+            BindingKind::Assignment | BindingKind::NamedExprAssignment => {
+                if matches!(
+                    existing.kind,
+                    BindingKind::Assignment | BindingKind::NamedExprAssignment
+                ) {
+                    return false;
+                }
+            }
             _ => {}
         }
-        // Otherwise, the shadowed binding must be a class definition, function definition, or
-        // import to be considered a redefinition.
+        // Otherwise, the shadowed binding must be a class definition, function definition,
+        // import, or assignment to be considered a redefinition.
         matches!(
             existing.kind,
             BindingKind::ClassDefinition(_)
                 | BindingKind::FunctionDefinition(_)
                 | BindingKind::Import(_)
                 | BindingKind::FromImport(_)
+                | BindingKind::Assignment
+                | BindingKind::NamedExprAssignment
         )
     }
 
