@@ -1,4 +1,4 @@
-use crate::server::client::Notifier;
+use crate::server::client::{Notifier, Requester};
 use crate::server::Result;
 use crate::session::Session;
 use lsp_types as types;
@@ -14,6 +14,7 @@ impl super::SyncNotificationHandler for DidChangeConfiguration {
     fn run(
         _session: &mut Session,
         _notifier: Notifier,
+        _requester: &mut Requester,
         _params: types::DidChangeConfigurationParams,
     ) -> Result<()> {
         // TODO(jane): get this wired up after the pre-release
